import { BaseSourceAdapter } from './base';
import { SourcePath } from '../types';
/**
 * Handles types with mixed content. Mixed content means there are one or more source
 * file(s) associated with a component with any file extension. Even an entire folder
 * can be considered "the content".
 *
 * __Example Types__:
 *
 * StaticResources, Documents, Bundle Types
 *
 * __Example Structures__:
 *
 *```text
 * foos/
 * ├── myFoo/
 * |   ├── fooFolder/
 * |      ├── foofighters.x
 * |   ├── foo.y
 * |   ├── fooBar.z
 * ├── myFoo.ext-meta.xml
 * bars/
 * ├── myBar.xyz
 * ├── myBar.ext2-meta.xml
 *```
 */
export declare class MixedContent extends BaseSourceAdapter {
    protected getMetadataXmlPath(pathToSource: SourcePath): SourcePath;
    protected getSourcePaths(fsPath: SourcePath, isMetaXml: boolean): SourcePath[];
    /**
     * "Content" can either be a single file or an entire folder. This will slice
     * the source path accordingly.
     * @param source
     */
    protected getPathToContent(source: SourcePath): SourcePath;
}
